
sjlog using logs/ch10.2, replace
use crspsubseta, clear
label define ind 1 Kappa 2 Lambda 3 Nu 4 Xi 5 Tau 6 Upsilon 7 Phi 8 Chi 9 Psi
quietly levelsof hiord, local(indices)
local nind : word count `indices'
quietly levelsof permno, local(firms)
local nf : word count `firms'
matrix retcorr = J(`nf', `nind', .)
sjlog close, replace


sjlog using logs/ch10.2a, replace
local n 0
quietly generate meanret = .
quietly generate ndays = .
local row = `nind' + 1
foreach f of local firms {
	quietly correlate index1-index`nind' ret if permno == `f'
	matrix sigma = r(C)
	local ++n
	forvalues i = 1/`nind' {
		matrix retcorr[`n', `i'] = sigma[`row', `i']
	}
	summarize ret if permno == `f', meanonly
	quietly replace meanret = r(mean) in `n'
	quietly replace ndays = r(N) in `n'
}
sjlog close, replace

sjlog using logs/ch10.2b, replace
svmat double retcorr
quietly egen double maxretcorr = rowmax(retcorr*) 
quietly generate highcorr = .
forvalues i = 1/`nind' {
	quietly replace highcorr = `i' if maxretcorr == retcorr`i' ///
	& !missing(maxretcorr) 
}
sjlog close, replace

sjlog using logs/ch10.2c, replace
gsort -meanret highcorr 
label values highcorr ind
list permno meanret ndays highcorr in 1/50, noobs separator(0)
sjlog close, replace

sjlog using logs/ch4.26.rev, replace
use hprice2a, clear
regress price nox dist rooms stratio proptax
sjlog close, replace

sjlog using logs/ch4.26.rev2, replace
margins, eyex(*) 
sjlog close, replace

sjlog using logs/ch4.26.rev4, replace
margins, eyex(stratio) at(stratio=(12(2)22))
marginsplot, ylabel(,angle(0))
sjlog close, replace

graph export fig4_2rev.eps, replace

sjlog using logs/ch10.1, replace
use litgov_estsample, clear
tabstat insider, by(insider) stat(N) save
return list
sjlog close, replace

sjlog using logs/ch10.1a, replace
makematrix t2a, from(r(Stat1) r(Stat2)): tabstat insider, by(insider) stat(N) save
summarize insider, mean
matrix temp = r(N)
matrix t2a = t2a, temp
sjlog close, replace

sjlog using logs/ch10.1b, replace
makematrix t2aa, from(r(Stat1) r(Stat2)): tabstat ceo, by(insider) stat(mean) save
matrix t2aa[1,1] = .
summarize ceo if insider, mean
matrix temp = r(N)
matrix t2aa = t2a \ (t2aa, temp)
sjlog close, replace

sjlog using logs/ch10.1c, replace
foreach v of varlist audit defendant_ANY ins_trade_ANY departed age tenure stkholding {
    quietly makematrix t2b, from(r(Stat1) r(Stat2)): tabstat `v', by(insider) stat(mean) save
    summarize `v', mean
    matrix `v'1 = r(N)
    quietly ttest `v', by(insider)
    matrix `v'2 = r(p)
    quietly ranksum `v', by(insider)
    matrix `v'3 = 1 - normprob(abs(r(z)))
    matrix `v' = t2b, `v'1, `v'2, `v'3
    matrix t2bb = (nullmat(t2bb) \ `v')
}
sjlog close, replace

sjlog using logs/ch10.1d, replace
matrix colnames t2aa = Outsider Insider Total
matrix rownames t2aa = Observations CEO
matrix list t2aa
matrix colnames t2bb = Outsider Insider N t_pval MW_pval
matrix list t2bb
sjlog close, replace

sjlog using logs/ch10.1e, replace
local inv Audit Defendant Ins\_Trading Departed Age Tenure Voting\_Share
local inv1 "Member Audit Committee (0/1)"
local inv2 "Defendant (0/1)"
local inv5 "Age (Years)"
local inv6 "Board Tenure (Years)"
local inv7 "Voting Share (\%)"
tempname hh
file open `hh' using table2.tex, write replace
file write `hh' "\begin{table}[htbp]\caption{Director-level variables}\bigskip" _newline

file write `hh' "\begin{tabular}{lrrrrr}" _newline "\hline" _newline
file write `hh' " Variable & Outside & Inside & & \multicolumn{2}{c}{\$p\$-value of Difference} \\" _newline
file write `hh' "& Directors & Directors & & \multicolumn{2}{c}{in Location} \\" _newline
file write `hh' "\hline & Mean & Mean & \$N\$ & \$t\$ test & Mann--Whitney \\" _newline
file write `hh' "\hline" _newline
file write `hh' "Observations (\$N\$) & " (t2aa[1, 1]) " & " (t2aa[1, 2]) " & " (t2aa[1, 3]) " \\" _newline
file write `hh' "\\{\sl Involvement} \\" _newline
file write `hh' "CEO (0/1) & N/A & " %7.3f (t2aa[2, 2]) " & " (t2aa[2, 3]) " \\" _newline
forvalues i = 1/2 {
	file write `hh' "`inv`i'' & "  %7.3f (t2bb[`i', 1]) " & "  %7.3f (t2bb[`i', 2]) " & " (t2bb[`i', 3])  " & " %7.3f (t2bb[`i', 4])  " & " %7.3f (t2bb[`i', 5]) " \\" _newline
}
file write `hh' "\\{\sl Outcome} \\" _newline
local i 4
file write `hh' "Departed (0/1) & "  %7.3f (t2bb[`i', 1]) " & "  %7.3f (t2bb[`i', 2]) " & " (t2bb[`i', 3])  " & " %7.3f (t2bb[`i', 4])  " & " %7.3f (t2bb[`i', 5]) " \\" _newline
file write `hh' "\\{\sl Demographics} \\" _newline
forvalues i = 5/7 {
	file write `hh' "`inv`i'' & "  %7.3f (t2bb[`i', 1]) " & "  %7.3f (t2bb[`i', 2]) " & " (t2bb[`i', 3])  " & " %7.3f (t2bb[`i', 4])  " & " %7.3f (t2bb[`i', 5]) " \\" _newline
}
file write `hh' "\hline" _n "\end{tabular}" "\medskip" _newline
file write `hh'  "\end{table}" _newline
file close `hh'
sjlog close, replace

sjlog using logs/ch10.4, replace
use airquality, clear
drop if town == "Alburq"
generate tabrv = upper(substr(town, 1, 3))
summarize temp, meanonly
generate hightemp = (temp > r(mean) & !missing(temp))
label define tlab 0 "below mean temp" 1 "above mean temp"
label values hightemp tlab
scatter so2 temp, msize(tiny) mlabel(tabrv) mlabsize(vsmall) ///
saving(fig10_4_1, replace) scheme(s2mono) ylabel(,angle(0))
scatter so2 precip, msize(tiny) mlabel(tabrv) mlabsize(vsmall) ///
by(hightemp) saving(fig10_4_2, replace) scheme(s2mono) ylabel(,angle(0))
scatter so2 wind, msize(tiny) mlabel(tabrv) mlabsize(vsmall) ///
by(hightemp) saving(fig10_4_3, replace) scheme(s2mono) ylabel(,angle(0))
sjlog close, replace

label variable precip "Mean precipitation indices"
label variable so2 "Sulphur dioxide, mg/m3"
scatter so2 precip, msize(tiny) mlabel(tabrv) mlabsize(vsmall) ///
by(hightemp) saving(fig10_4_2, replace) scheme(s2mono) ylabel(,angle(0))

graph export fig10_4.eps, replace

sjlog using logs/ch10.4a, replace
clear
serset clear
graph use fig10_4_1
serset dir
serset use
sort tabrv
save f10_4_1, replace
sjlog close, replace

sjlog using logs/ch10.4b, replace
serset clear
graph use fig10_4_2
serset dir
serset set 0
serset use
sort tabrv
save f10_4_2, replace
serset set 1
serset use
sort tabrv
save f10_4_2a, replace
serset clear
graph use fig10_4_3
serset dir
serset set 0
serset use
sort tabrv
save f10_4_3, replace
serset set 1
serset use
sort tabrv
save f10_4_3a, replace
sjlog close, replace

sjlog using logs/ch10.4c, replace
use f10_4_1, clear
merge 1:1 tabrv using f10_4_2  
drop _merge
merge 1:1 tabrv using f10_4_3
drop _merge
sort tabrv
merge 1:1 tabrv using f10_4_2a, update
drop _merge
sort tabrv 
merge 1:1 tabrv using f10_4_3a, update
drop _merge
save f10_4_all, replace
describe
summarize
sjlog close, replace

sjlog using logs/ch10.6, replace
use crudeoil, clear
list in 1/51, sepby(qmdy)
sjlog close, replace

sjlog using logs/ch10.6a, replace
// identify last day of trading for near contract in each month
bysort qmdy (cmdy): generate near = contract if _n == 1 
sjlog close, replace

sjlog using logs/ch10.6b, replace
// qmdy is the first date when the near contract is no longer quoted
// that minus 3 trading days is the target rollover date
bysort cmdy (qmdy): generate rolldate = qmdy[_n-3] if near[_n] != near[_n-1] 
bysort cmdy (qmdy): generate roll1date = qmdy[_n-4] if near[_n] != near[_n-1] 
bysort cmdy (qmdy): generate nnear = contract if near[_n] != near[_n-1]
// fixup for first obs
replace nnear = . in 1
sjlog close, replace

sjlog using logs/ch10.6c, replace
bysort qm: egen rollover = mean(rolldate)
bysort qm: egen rollover1 = mean(roll1date)
bysort qm: egen nextnear = mean(nnear)
sjlog close, replace

sjlog using logs/ch10.6d, replace
// calculate price series as settle(near) for pre-rollover dates
bysort qm: generate futprice = settle if contract == near & qmdy < rollover
// calculate price series as settle(nnear) for rollover date et seq.
bysort qm: replace futprice = settle if contract==nextnear & qmdy >= rollover
format futprice %9.2f
// calculate return series for the rollover date
bysort qm: generate settleprev = settle if contract == nextnear & qmdy == rollover1
bysort qm: egen sprev = mean(settleprev)
bysort qm: generate double futret = log(settle) - log(sprev) if qmdy == rollover
// drop obs no longer needed, flagged by missing settle
drop if futprice == .
// calc returns for all non-settle dates
sort qmdy
replace futret = log(settle) - log(settle[_n-1]) if missing(futret)
sjlog close, replace

format rollover %td

sjlog using logs/ch10.6e, replace
sort qmdy cmdy
list qmdy contract futprice futret if !missing(futprice) in 1/62,  noobs sepby(qm)
sjlog close, replace
