clear all

sjlog using logs/ch14.1, replace
type flipmat.ado
sjlog close, replace

do mf_flipmat.mata

sjlog using logs/ch14.1a, replace
type mf_flipmat.mata
sjlog close, replace

clear
set obs 25
set seed 20071110
generate id = int(1000*runiform())
generate hw = int(50*runiform()+5)
generate mt = int(2*hw + 5*invnormal(runiform()))
generate final = int(4*hw + 7*invnormal(runiform()))
generate total = hw + mt + final
sort total
summarize
mkmat hw mt final total, matrix(grades)
mkmat id, matrix(id)
forvalues i=1/25 {
	local id = string(id[`i',1])
	local idnr "`idnr' `id'"
}
matrix rownames grades = `idnr'

sjlog using logs/ch14.1b, replace
use course, clear
matrix list grades, noheader
sjlog close, replace

sjlog using logs/ch14.1c, replace
flipmat grades
matrix list grades, noheader
sjlog close, replace

sjlog using logs/ch14.1d, replace
flipmat grades, horiz
matrix list grades, noheader
sjlog close, replace

sjlog using logs/ch14.2a, replace
type shufstr.ado
sjlog close, replace

do shufstr.mata

sjlog using logs/ch14.2b, replace
type shufstr.mata
sjlog close, replace

sjlog using logs/ch14.2, replace
sysuse auto, clear
generate model = ""
quietly describe
forvalues i = 1/`=r(N)' {
	local temp = make[`i']
	local model: word 2 of `temp'
	quietly replace model = "`model'" in `i'
}
keep in 1/15
keep make model price
generate shufmod = model
set seed 20141231
shufstr(shufmod)
list, separator(0) noobs
sjlog close, replace

do indcorr.mata

sjlog using logs/ch14.3a, replace
type indcorr.mata
sjlog close, replace

sjlog using logs/ch14.3b, replace
use ch14_3, clear
maxindcorr index1-index9, ret(ret) firm(permno) gen(set1)
summarize set1*
gsort -set1mu
label define ind 1 Kappa 2 Lambda 3 Nu 4 Xi 5 Tau 6 Upsilon 7 Phi 8 Chi 9 Psi
label values set1max ind
list set1permno set1mu set1n set1max in 1/50, noobs separator(0)
sjlog close, replace

sjlog using logs/ch14.4, replace
type aggreg2.ado
sjlog close, replace

sjlog using logs/ch14.4a, replace
type aggreg2.mata
sjlog close, replace

do aggreg2.mata

sjlog using logs/ch14.4b, replace
use urates, clear
aggreg2 tenn, per(3) trans(log) // calculate quarterly averages of log(tenn)
aggreg2 tenn, per(3) func(sum) trans(sqrt) // calculate quarterly sum of sqrt(tenn)
tsmktim quarter, start(1978q1) // create quarterly calendar var
list t tenn quarter tennAlog3 tennSsqrt3 in 1/12, separator(3)
sjlog close, replace

sjlog using logs/ch14.5, replace
sysuse auto, clear
generate en = _n
mata:
st_view(Z1=., ., ("en", "price", "mpg", "turn"), 0)
st_view(Z2=., ., ("en", "weight", "length", "rep78"), 0)
Z1[ 6, .]
Z2[ 6, .]
end
sjlog close, replace

mata: mata clear
do country.mata

sjlog using logs/ch14.6,replace
type country.mata
sjlog close, replace

do loadcty.mata

sjlog using logs/ch14.6a, replace
type loadcty.mata
sjlog close, replace

do compcty.mata

sjlog using logs/ch14.6b, replace
type compcty.mata
sjlog close, replace

mata: mata clear
do country.mata
do loadcty.mata
do compcty.mata
sjlog using logs/ch14.6c, replace
mata: 
addr1 = loadcty("US", "United States", 301.139947, 43800,"Washington DC", 38, 53, -77, -02)
addr2 = loadcty("CA", "Canada", 33.390141, 35700, "Ottawa", 45, 24, -75, -43)
addr3 = loadcty("TR", "Turkey", 71.158647, 9100, "Ankara", 39, 55, 32, 55)
addr4 = loadcty("AR", "Argentina", 40.301927, 15200, "Buenos Aires", -34, -35, 58, 22)
addr5 = loadcty("JP", "Japan", 127.433494, 33100, "Tokyo", 35, 40, 139, 45)
end
clear
set obs 1
generate lat1 = .
generate long1 = .
generate lat2 = .
generate long2 = .
sjlog close, replace

sjlog using logs/ch14.6d, replace
mata: 
compcty(*addr1, *addr2)
compcty(*addr1, *addr3)
compcty(*addr3, *addr4)
compcty(*addr1, *addr5)
end
sjlog close, replace

do compcty2.mata

sjlog using logs/ch14.6e, replace
type compcty2.mata
sjlog close, replace

sjlog using logs/ch14.6f, replace
mata:
compcty2(*addr1, *addr3)
compcty2(*addr3, *addr4)
end
sjlog close, replace

sjlog using logs/ch14.7, replace
type nneighbor.ado
sjlog close, replace

do mf_nneighbor.mata

sjlog using logs/ch14.7a, replace
type mf_nneighbor.mata
sjlog close, replace

do mf_nneighbor.mata

sjlog using logs/ch14.7b, replace
use usairquality, clear
sort pop
nneighbor pop, y(so2) matchobs(mo1) matchval(mv1)
list pop mo1 so2 mv1, separator(0)
sjlog close, replace

sjlog using logs/ch14.7c, replace
nneighbor pop temp wind, y(so2) matchobs(mo3) matchval(mv3)
nneighbor pop temp wind precip days, y(so2) matchobs(mo5) matchval(mv5)
sjlog close, replace

sjlog using logs/ch14.7aa, replace
webuse nlsw88, clear
// get the number of occupation codes
summarize occupation, meanonly
scalar nocc = r(max)

mata:
occs = st_vlmap("occlbl",(1..st_numscalar("nocc")))'
// get permutation vector for alpha-sorted occupations
permv = order(occs, 1)
occsort = occs[(permv),.]
end
sjlog close, replace

sjlog using logs/ch14.7ab, replace
quietly regress wage i.occupation married
margins occupation, post
sjlog close, replace

sjlog using logs/ch14.7ac, replace
mata:
b = st_matrix("e(b)")
bord = b[(permv)]'
V = st_matrix("e(V)")
seord = diagonal(sqrt(V[(permv),(permv)]))

for(i=1; i<=rows(occsort); i++) {
	if (i==1) {
		printf("\nMean wage by occupation, conditional on marital status \n{hline 45}\n")
	}
	printf("%s {col 25} %9.3f  (%5.3f) \n", occsort[i], bord[i], seord[i])
	if (i==rows(occsort)) {
		printf("{hline 45}\n\n")
	}
}

end
sjlog close, replace


do demotabOpen.mata

sjlog using logs/ch14.7ba, replace
type demotabOpen.mata
sjlog close, replace

do demotab.mata

sjlog using logs/ch14.7bb, replace
type demotab.mata
sjlog close, replace

sjlog using logs/ch14.8ab, replace
use mus03data, clear
drop if mi(ltotexp)
eststo clear
foreach q in 0.25 0.50 0.75 {
eststo, title("Q(`q')"): qregmargins ltotexp suppins totchr age female white, q(`q')
}
sjlog close, replace

sjlog using logs/ch14.8ac, replace
esttab, replace nonumbers nodepvars mtitles drop(_cons) star(* 0.1 ** 0.05 *** 0.01) ///
title("Quantile regression: Marginal effects on total expenditure")
sjlog close, replace

do mm_suregub.mata

sjlog using logs/ch14.8a, replace
type mm_suregub.mata
sjlog close, replace

do mm_suregub.mata

sjlog using logs/ch14.8b, replace
use grunfeld, clear
drop in 75/80
drop in 41/43
drop in 18/20
keep if company <= 4
drop time
reshape wide invest mvalue kstock, i(year) j(company)
list year invest*, separator(0)
sjlog close, replace


sjlog using logs/ch14.8c, replace
suregub (invest1 mvalue1 kstock1) (invest2 mvalue2 kstock2) ///
        (invest3 mvalue3 kstock3) (invest4 mvalue4 kstock4) 
sjlog close, replace

sjlog using logs/ch14.9b, replace
type mygmm2s.ado
sjlog close, replace

set matastrict on
do m_mygmm2s.mata

sjlog using logs/ch14.9c, replace
type m_mygmm2s.mata
sjlog close, replace

do m_myomega.mata

sjlog using logs/ch14.9d, replace
type m_myomega.mata
sjlog close, replace


sjlog using logs/ch14.9e, replace
type mygmmcue.ado
sjlog close, replace

do m_mygmmcue.mata

sjlog using logs/ch14.9f, replace
type m_mygmmcue.mata
sjlog close, replace


do m_mycuecrit.mata

sjlog using logs/ch14.9g, replace
type m_mycuecrit.mata
sjlog close, replace


set matastrict on
do m_mygmm2s.mata
do m_myomega.mata
do m_mygmmcue.mata
do m_mycuecrit.mata

sjlog using logs/ch14.9, replace
cscript mygmm2s adofile mygmm2s
set more off
use griliches76, clear
quietly ivreg2 lw s expr tenure rns smsa (iq=med kww age mrt), gmm2s 
storedresults save ivhomo e()
mygmm2s lw, endog(iq) inexog(s expr tenure rns smsa) ///
            exexog(med kww age mrt)
storedresults compare ivhomo e(), include(macros: depvar scalar: N j matrix: b V) ///
             tol(1e-7) verbose
quietly ivreg2 lw s expr tenure rns smsa (iq=med kww age mrt), gmm2s robust
storedresults save ivrobust e()
quietly mygmm2s lw, endog(iq) inexog(s expr tenure rns smsa) ///
                    exexog(med kww age mrt) robust
storedresults compare ivrobust e(), include(macros: depvar scalar: N j matrix: b V) /// 
             tol(1e-7) verbose
sjlog close, replace


sjlog using logs/ch14.9a, replace
cscript mygmmcue adofile mygmmcue
set more off
set rmsg on
use griliches76, clear
quietly ivreg2 lw s expr tenure rns smsa (iq=med kww age mrt), cue 
storedresults save ivreg2cue e()
mygmmcue lw, endog(iq) inexog(s expr tenure rns smsa) ///
            exexog(med kww age mrt)
storedresults compare ivreg2cue e(), include(macros: depvar scalar: N j matrix: b V) ///
             tol(1e-4) verbose
quietly ivreg2 lw s expr tenure rns smsa (iq=med kww age mrt), cue robust
storedresults save ivreg2cue e()
mygmmcue lw, endog(iq) inexog(s expr tenure rns smsa) ///
            exexog(med kww age mrt) robust
storedresults compare ivreg2cue e(), include(macros: depvar scalar: N j matrix: b V) ///
             tol(1e-4) verbose
sjlog close, replace

set rmsg off
