use census2c, clear
sjlog using logs/ch3.01, replace
summarize pop*
sjlog close, replace

sjlog using logs/ch3.02, replace
list state pop in 1/5
list state pop medage if medage >= 32
sjlog close, replace

sjlog using logs/ch3.03, replace
encode state, generate(stateid)
describe state stateid
list state stateid in 1/5
sjlog close, replace

sjlog using logs/ch3.04, replace
decode stateid, generate(statename)
list stateid statename in 1/5
sjlog close, replace

display `"This is a "quoted" string."'

sjlog using logs/ch2.03, replace
generate urbanized = popurb / pop
summarize urbanized
sjlog close, replace

sjlog using logs/ch2.04, replace
replace urbanized = 100 * urbanized
summarize urbanized
sjlog close, replace

sjlog using logs/ch3.06, replace
generate byte newengland = inlist(state, "Connecticut", "Maine", ///
"Massachusetts", "New Hampshire", "Rhode Island", "Vermont")
sort medage
list state medage pop if newengland, separator(0)
sjlog close, replace

sjlog using logs/ch3.07, replace
list state medage pop if inrange(pop, 5000, 9999), separator(0)
sjlog close, replace

sjlog using logs/ch2.09, replace
generate smallpop = 0 
replace smallpop = 1 if pop <= 5000 & !missing(pop)
generate largepop = 0
replace largepop = 1 if pop > 5000 & !missing(pop)
list state pop smallpop largepop, separator(0)
sjlog close, replace

sjlog using logs/ch2.10, replace
generate netmarr2x = cond(marr/divr > 2.0, 1, 2)
label define netmarr2xc 1 "marr > 2 divr" 2 "marr <= 2 divr"
label values netmarr2x netmarr2xc
tabstat pop medage, by(netmarr2x)
sjlog close, replace

sjlog using logs/ch3.07a, replace
generate medagebrack = recode(medage, 29, 30, 31, 32, 33)
tabulate medagebrack
sjlog close, replace

sjlog using logs/ch3.05, replace
generate size=irecode(pop, 1000, 4000, 8000, 20000)
label define popsize 0 "<1m" 1 "1-4m" 2 "4-8m" 3 ">8m"
label values size popsize
tabstat pop, stat(mean min max) by(size)
sjlog close, replace

sjlog using logs/ch3.07c, replace
xtile medagequart = medage, nq(4)
tabstat medage, stat(n mean min max) by(medagequart)
sjlog close, replace

sjlog using logs/ch3.08, replace
bysort size: egen avgpop = mean(pop)
generate popratio = 100 * pop / avgpop
format popratio %7.2f
list state pop avgpop popratio if size == 0, separator(0)
sjlog close, replace

sjlog using logs/ch2.026, replace
gsort region -pop
by region: generate totpop = sum(pop)
list region state pop totpop, sepby(region)
sjlog close, replace

sjlog using logs/ch2.027, replace
by region: list region totpop if _n == _N
sjlog close, replace

sjlog using logs/ch2.029, replace
generate popsize = smallpop + 2*largepop
label variable popsize "Population size code"
label define popsize 1 "<= 5 million" 2 "> 5 million", modify
label values popsize popsize
bysort region popsize: egen meanpop2 = mean(pop)
list region popsize state pop meanpop2, sepby(region popsize)
sjlog close, replace

set more off
sjlog using logs/ch3.10, replace
use fem2, clear
local anxlevel None Mile Moderate Severe
display "The defined levels of anxiety are: `anxlevel'"
sjlog close, replace

sjlog using logs/ch3.11, replace
local count 0
local anxlevel None Mild Moderate Severe
foreach a of local anxlevel {
     local count `count' + 1
     display "Anxiety level `count': `a'"
}
sjlog close, replace

sjlog using logs/ch3.12, replace
local count 0
local anxlevel None Mild Moderate Severe
foreach a of local anxlevel {
     local count = `count' + 1
     display "Anxiety level `count': `a'"
}
sjlog close, replace

sjlog using logs/ch3.13, replace
local count 0
local anxlevel None Mild Moderate Severe
foreach a of local anxlevel {
     local count `count' + 1
     local newlist "`newlist' `count' `a'"
}
display "`newlist'"
sjlog close, replace

sjlog using logs/ch3.14, replace
local anxlevel None Mild Moderate Severe
local wds: word count `anxlevel'
display "There are `wds' anxiety levels:"
forvalues i = 1/`wds' {
     local wd: word `i' of `anxlevel'
     display "Level `i' is `wd'"
}
sjlog close, replace

sjlog using logs/ch3.15, replace
use fem2, clear
scalar root2 = sqrt(2.0)
generate double rootage = age * root2
sjlog close, replace

sjlog using logs/ch3.16, replace
use fem2, clear
scalar lb1 = 80
scalar ub1 = 88
scalar lb2 = 89
scalar ub2 = 97
scalar lb3 = 98
scalar ub3 = 109
forvalues i = 1/3 {
     display _n "IQ " lb`i' " = " ub`i'
     tabulate anxiety if inrange(iq, lb`i', ub`i')
}
sjlog close, replace

sjlog using logs/ch3.17, replace
use fem2, clear
regress weight c.age##c.age
matrix b = e(b)
matrix V = e(V)
matrix list b
matrix list V
sjlog close, replace

