
sjlog using logs/ch9.01, replace
use grunfeldavg, clear
levelsof company, local(colist)
local ncomp : word count `colist'
matrix table1 = J(`ncomp', 7, 0)
sjlog close, replace

sjlog using logs/ch9.01a, replace
local i 0
levelsof company, local(colist)
foreach c of local colist {
	quietly {
		local ++i
		summarize invest if company == `c', detail
		matrix table1[`i', 1] = r(p25)
		matrix table1[`i', 2] = r(p50)
		matrix table1[`i', 3] = r(p75)
		correlate invest invavg if company == `c'
		matrix table1[`i', 4] = r(rho)
		correlate kstock kapavg if company == `c'
		matrix table1[`i', 5] = r(rho)
		regress invest L.kstock L.kapavg if company == `c'
		matrix table1[`i', 6] = _b["L.kstock"]
		matrix table1[`i', 7] = _se["L.kstock"]
	}
}
matrix rownames table1 = `colist'
matrix colnames table1 = p25 p50 p75 rinvest rkap betak sek
sjlog close, replace

sjlog using logs/ch9.02, replace
matrix list table1, format(%9.3f) title("Grunfeld company statistics")
sjlog close, replace

sjlog using logs/ch9.02a, replace
outtable using ch9.02t, mat(table1) replace ///
format(%9.3f) center nobox caption("Grunfeld company statistics")
sjlog close, replace

use grunfeldavg, clear
sjlog using logs/ch9.03, replace
levelsof company, local(colist)
local ncomp : word count `colist'
forvalues i = 1/`ncomp' {
	local c : word `i' of `colist'
	quietly regress invest L(1/2).kstock L.kapavg if company == `c'
        matrix beta`i' = e(b)
        matrix allbeta = (nullmat(allbeta) \ beta`i')
        local row "`row' `c'"
}
matrix rownames allbeta = `row'
sjlog close, replace

outtable using ch9.03t, mat(allbeta) replace  ///
format(%9.4f) center nobox caption("Grunfeld company estimates")

sjlog using logs/ch9.04, replace
use grunfeldavg, clear
levelsof company, local(colist)
local ncomp : word count `colist'
tempname p
postfile `p' compnr p25 p50 p75 rinvest rkap betak sek using firmstats, replace
sjlog close, replace

sjlog using logs/ch9.04a, replace
forvalues i = 1/`ncomp' {
	local c : word `i' of `colist'
	quietly {
		summarize invest if company == `c', detail
		local p25 = r(p25)
		local p50 = r(p50)
		local p75 = r(p75)
		correlate invest invavg if company == `c'
		local rinvest = r(rho)
		correlate kstock kapavg if company == `c'
		local rkap = r(rho)
		regress invest L.kstock L.kapavg if company == `c'
	}
	post `p' (`i') (`p25') (`p50') (`p75') (`rinvest') (`rkap') ///
	(_b["L.kstock"]) (_se["L.kstock"]) 
}
postclose `p'
sjlog close, replace

sjlog using logs/ch9.04b, replace
use firmstats, clear
summarize
sjlog close, replace

sjlog using logs/ch9.05, replace
tempname fh
file open `fh' using matout.raw, write replace
sjlog close, replace

sjlog using logs/ch9.05a, replace
local rows = rowsof(table1)
local cols = colsof(table1)
local timestamp "Matrix created `c(current_date)' `c(current_time)'"
file write `fh' "`timestamp'" _n
file write `fh' "`rows' `cols'" _n
forvalues i = 1/`rows' {
	forvalues j = 1/`cols' {
		file write `fh' (table1[`i', `j']) " "
	}
	file write `fh' _n
}
file close `fh'
sjlog close, replace

sjlog using logs/ch9.05b, replace
tempname fh
file open `fh' using matout2.raw, write replace
local rows = rowsof(table1)
local cols = colsof(table1)
local timestamp "Matrix created `c(current_date)' `c(current_time)'"
file write `fh' "`timestamp'" _n
file write `fh' "`rows' `cols'" _n
local coln : colnames table1
local rown : rownames table1
file write `fh' "firmno `coln'" _n
forvalues i = 1/`rows' {
	local rn : word `i' of `rown'
	file write `fh' `"`rn' "'
	forvalues j = 1/`cols' {
		file write `fh' (table1[`i', `j']) " "
	}
	file write `fh' _n
}
file close `fh'
sjlog close, replace

sjlog using logs/ch9.05c, replace
type matout2.raw
sjlog close, replace

sjlog using logs/ch9.06, replace
use wagepan, clear
xtset nr year
generate lhours = log(hours)
sjlog close, replace

sjlog using logs/ch9.07, replace
forvalues y = 1980/1987 {
	quietly {
		eststo clear
		regress lwage educ lhours  if year == `y'
		margins, dyex(educ)
		matrix eta = r(b)
		matrix s2eta = r(V)
		matrix list eta
		matrix list s2eta
		eststo, add(eta_educ eta[1, 1] s_educ sqrt(s2eta[1, 1]))
		regress lwage educ lhours black hisp if year == `y'
		margins, dyex(educ)
		matrix eta = r(b)
		matrix s2eta = r(V)
		matrix list eta
		matrix list s2eta
		eststo, add(eta_educ eta[1, 1] s_educ sqrt(s2eta[1, 1]))
		regress lwage educ c.exper##c.exper lhours black hisp if year == `y'
		margins, dyex(educ exper)
		matrix eta = r(b)
		matrix s2eta = r(V)
		matrix list eta
		matrix list s2eta
		eststo, add(eta_educ eta[1, 1] s_educ sqrt(s2eta[1, 1]) ///
			eta_exper eta[1, 2] s_exper sqrt(s2eta[2, 2]))
 	}
	esttab _all using lwage`y'.tex, replace title("Wage equations for `y'") ///
	       label nomtitles nodepvars not se noobs ar2 booktabs ///
	       scalar(eta_educ s_educ eta_exper s_exper) ///
	       addnotes("$\eta$: semielasticity of lwage with respect to educ, exper" ///
	       "$\eta_{se}$: standard error of the semielasticity") ///
	       substitute("_cons" "constant" "eta_educ" "$\eta_{educ}$" ///
	       "s_educ" "$\eta_{se}$" "eta_exper" "$\eta_{exper}$" "s_exper" "$\eta_{se}$" ///
		   "c.exper#c.exper" "experience$^2$") 
}
sjlog close, replace

sjlog using logs/putexcel, replace
putexcel set lwages, sheet(1980)
local beta = ustrunescape("\u03B2")
putexcel B2="`beta'" B3=matrix(eta) C2="S.E." C3=matrix(s2eta)
sjlog close, replace

sjlog using logs/ch9.08, replace
separate lwage, by(black | hisp) veryshortlabel
forvalues y = 1981/1987 {
	quietly {
	regress lwage educ exper lhours if year == `y'
	scatter lwage0 lwage1 lhours if year==`y', msize(small) ///
	        scheme(s2mono) nodraw ///
	        name(scat`y',replace) ytitle(lwage) legend(pos(5) ring(0) col(1))
	avplot lhours, msize(small) nodraw scheme(s2mono) name(avplot`y', replace) 
	graph combine scat`y' avplot`y', nodraw col(2) saving(lwage`y', replace) ///
	      title("Log wage vs. log hours for `y'") 
	}
}
sjlog close, replace

graph use lwage1984
graph display, xsize(5) ysize(3)
graph export fig9_1.eps, replace


sjlog using logs/ch9.10, replace
sysuse auto, clear
char make[varname] "genre"
char price[varname] "prix"
char weight[varname] "poids"
char length[varname] "longueur"
char displacement[varname] "volume"
sjlog close, replace

sjlog using logs/ch9.11, replace
list make price weight length displacement in 1/10, separator(0)
list make price weight length displacement in 1/10, separator(0) subvarname
sjlog close, replace



